
#ifndef _GALIL_1800_H_
#define _GALIL_1800_H_

#define GALIL1800_MODULE_NAME        "galil1800"
#define PFX                          GALIL1800_MODULE_NAME ": "
#define DEBUG_PFX                    PFX "DEBUG: "

/* print debug managemant */
#ifdef GALIL1800_DEBUG
#  define GALIL_PRINT_DEBUG(format_string, args...)      \
        printk(KERN_DEBUG DEBUG_PFX format_string, ##args)
#else /* print debug disabled */
#  define GALIL_PRINT_DEBUG(format_string, args...)
#endif


#define PLX_PCI_VENDOR_ID            0x10B5
#define PLX_PCI_DEVICE_ID            0x9050
#define GALIL_SUB_VENDOR             0x1079
#define GALIL_SUB_DEVICE_1800        0x1800

/* The Base Address Register index in the PCI configuration space */
#define GALIL1800_DPRAM_BAR_INDEX           0
#define GALIL1800_REG_BAR_INDEX             2

/* The PCI resource lenght at REG BAR */
#define GALIL1800_REG_PCI_RESOURCE_LEN   16


#include <linux/spinlock.h>
#include <linux/init.h>

struct galil1800_state {
	unsigned long io;        /* io port address  */
	/* io memory: */
	unsigned long mem_paddr; /* physical address */
	void *mem_vaddr;         /* virtual address  */
	unsigned long mem_size;  /* size             */

	unsigned long ctrl_reg;    /* control register I/O address */
	unsigned long irq_reg;     /* irq register I/O address */
	unsigned long chan2_reg;   /* secondary channel register I/O address */

	unsigned int irq;          /* IRQ line number */

	spinlock_t hwlock;         /* spin lock for low-level fiddling */
};

extern int
	galil1800_init_controller_probe_step(struct galil1800_state*) __init;


#endif
