
#include "galil1800_io.h"

/* Initialize the controller
   Used in PCI probe function
   Return < 0 if errors, 0 otherwise */
int __init galil1800_init_controller_probe_step(struct galil1800_state *s)
{
	const char *RS = "RS\r";
	unsigned long j;
	char buf[GALIL1800_READ_FIFO_SIZE+1];
	int ret, n;

	galil1800_reset_fifo_rw(s);

	/* check if FIFO is really flushed */
	n = galil1800_may_write(s);
	if (0==n || 1==n)
		return -EIO;

	galil1800_send(s, RS, strlen(RS));
	j = jiffies + 5*HZ; /* 5 second timeout */

	n=0;

	/* RS can return ":" or "RS\r:" if echo is enabled */
	do {
		ret=galil1800_recv(s, buf+n, GALIL1800_READ_FIFO_SIZE-n);
		if(!ret) {
			schedule();
			continue;
		}
		n+=ret;
		if (buf[n-1] == ':')
			break;
	}while(time_before(jiffies,j));

	if (!n) {
		printk(KERN_NOTICE PFX "RS command timed out."
				" Performing hardware reset\n");
		galil1800_reset_hardware(s);
	} else if (buf[n-1] != ':') {
		buf[n]='\0';
		printk(KERN_ERR PFX
			"RS command failed! It returned \"%s\"\n", buf);
		return -EIO;
	}

	GALIL_PRINT_DEBUG("device initialized\n");

	return 0;
}
